@@ -120,7 +120,7 @@ class WorkerServer(BaseServer):
         self.auth = yield self.conn.authenticate(
             self.amqp_username,
             self.amqp_password)
-        self.chan = yield self.conn.channel(long(random.getrandbits(16)))
+        self.chan = yield self.conn.channel(random.randint(2, 999))
         yield self.chan.channel_open()
         yield self.chan.basic_qos(prefetch_count=self.amqp_prefetch_count)
         # Create Queue
